gossan-techstack 0.3.3

Tech stack fingerprinting scanner for gossan, powered by truestack, part of the security research ecosystem
docs.rs failed to build gossan-techstack-0.3.3
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: gossan-techstack-0.3.2

gossan-techstack

Part of the Santh security research ecosystem.

Tech stack fingerprinting scanner for panoram (powered by truestack (part of the Santh security research ecosystem)).

Part of gossan.

Usage

```rust
use gossan_techstack::TechStackScanner;
// Fingerprints web technologies using truestack

## License

MIT